==> haskell-path-io-1.8.2-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-HtaRpKOeeeb4JUH14GSScm
key:                  path-io-1.8.2-HtaRpKOeeeb4JUH14GSScm
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  8c3915ddf7d03cae91cd83dbfd90f3e3
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-HtaRpKOeeeb4JUH14GSScm
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI exceptions-0.10.5 filepath-1.4.2.2
    path-0.9.5-83oii1WRW5S7hS9dJHFOfm
    temporary-1.3-4U3e01RislmEUeJgFruRX5 time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-7wl3VN2bkjVLyACPiFBxN

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.8.2-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-CocIhXeP9tXKdIZmEsJIzv
key:                  path-io-1.8.2-CocIhXeP9tXKdIZmEsJIzv
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  ad9e3eaa250ac347b6ee3ac0a030e722
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-CocIhXeP9tXKdIZmEsJIzv
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI exceptions-0.10.5 filepath-1.4.2.2
    path-0.9.5-Fe7GJgad0iMHiVJ0YaeB5L
    temporary-1.3-9g1OGPiytt1BO3oUGnOgqn time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-9t2FupNpdHvF9CotjWq7e6

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
